slack_notifier library

Classes

ActionsBlock
Holds multiple interactive elements.
Attachment
Block
ContextBlock
Displays contextual info, which can include both images and text.
DividerBlock
Visually separates pieces of info inside of a message.
Field
FileBlock
Displays a remote file. You can't add this block to app surfaces directly, but it will show up when retrieving messages that contain remote files.
HeaderBlock
Displays a larger-sized text block. Use it to delineate between different groups of content in your app's surfaces.
ImageBlock
Displays an image. An image block, designed to make those cat photos really pop.
InputBlock
Collects information from users via block elements.
RichTextBlock
Displays formated, structured representation of text.
SectionBlock
Displays text, possibly alongside block elements. A section can be used as a text block, in combination with text fields, or side-by-side with certain block elements.
SlackNotifier
VideoBlock
Displays an embedded video player. A video block is designed to embed videos in all app surfaces (e.g. link unfurls, messages, modals, App Home) - anywhere you can put blocks.